ExLLama.Nif
(LLama CPP Nif Wrapper v0.2.1)
C NIF bindings for llama.cpp — bridges old API names to new C NIF functions and wraps raw references in the expected structs.
C NIF bindings for llama.cpp — bridges old API names to new C NIF functions and wraps raw references in the expected structs.